@@ -22,10 +22,15 @@
 Common models related to image.
 """
 
-import math
+import math, md5, os
 from elisa.core.components.model import Model
 from elisa.core.utils.i18n import install_translation
 
+from elisa.plugins.base.models.file import FileModel
+from elisa.plugins.base.models.media import RawDataModel
+
+from twisted.internet import defer
+
 pi = math.pi
 
 ROTATED_0=1
@@ -60,6 +65,13 @@ IMAGE_ORIENTATIONS={ROTATED_0: (_('Horizontal (normal)'),
                     }
 
 
+# for the caching we have to make sure that the picture cache is existing.
+from elisa.core.default_config import PICTURES_CACHE
+
+if not os.path.exists(PICTURES_CACHE):
+    os.makedirs(PICTURES_CACHE, 0755)
+
+
 class ImageModel(Model):
 
     """
@@ -100,3 +112,38 @@ class ImageModel(Model):
         self.references = []
         self.orientation = ROTATED_0
         self.can_rotate = True
+
+    def get_cached_data_path(self, reference_num):
+        uri = self.references[reference_num]
+        path = self._compute_cached_path(uri)
+
+        if os.path.exists(path):
+            # already cached
+            return defer.succeed(path)
+
+        dfr = self._retrieve_raw_data_model(uri)
+        dfr.addCallback(self._cache_raw_data, path)
+        return dfr
+
+    
+    def _compute_cached_path(self, uri):
+        filename = md5.new(str(uri)).hexdigest() + '.' + uri.extension
+        path = os.path.join(PICTURES_CACHE, filename)
+        return path
+
+    def _cache_raw_data(self, raw_data_model, path):
+        if isinstance(raw_data_model, FileModel):
+            # this is conceptionally wrong. we should not get it here at all!
+            return raw_data_model.uri.path
+
+        fd = open(path, 'wb')
+        fd.write(raw_data_model.data)
+        fd.close()
+        return path
+
+    def _retrieve_raw_data_model(self, uri):
+        from elisa.core import common
+        resource_manager = common.application.resource_manager
+
+        model, dfr = resource_manager.get(uri)
+        return dfr
