@@ -42,3 +42,21 @@ class VideoModel(Model):
         """
         super(VideoModel, self).__init__()
         self.playable_uri = None
+        
+    def get_playable_model(self):
+        """
+        Return a deferred that will return an instance of
+        L{elisa.plugins.base.models.media.PlayableModel} for the video.
+
+        @rtype:  L{elisa.core.utils.defer.Deferred}
+        """
+        return defer.fail(NotImplementedError())
+        
+    def get_poster(self):
+        """
+        Return a deferred that will return the local path of the video poster
+        (if available)
+
+        @rtype:  L{elisa.core.utils.defer.Deferred}
+        """
+        return defer.fail(NotImplementedError())
