@@ -23,14 +23,17 @@ This Component can block the GnomeScreenSaver in different modes. That
 is very useful, if you have a remote control or other input device
 which is not reconized by the Screensaver on its own.
 
-This Compontent blocks with this usage also the PowerManager of GNOME,
+This Component blocks with this usage also the PowerManager of GNOME,
 so that the sleep/Screen procedures shouldn't happen.
-
 """
 
 from elisa.core.components.service_provider import ServiceProvider
 from elisa.core import common
-from elisa.core.application import ComponentsLoadedMessage
+
+try:
+    from elisa.plugins.pigment.message import PigmentFrontendLoadedMessage
+except ImportError:
+    PigmentFrontendLoadedMessage = None
 
 import dbus
 if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
@@ -39,6 +42,7 @@ from dbus.exceptions import DBusException
 
 from twisted.internet import defer
 
+
 class GnomeScreensaverService(ServiceProvider):
     """
     This class connect to the Gnome Screen Saver and blocks it
@@ -83,8 +87,13 @@ class GnomeScreensaverService(ServiceProvider):
             blocking_mode = self.config.get('blocking_mode', 1)
             if blocking_mode == 1:
                 self.info("Using the stop-on-playing-only mode")
+                if PigmentFrontendLoadedMessage is None:
+                    self.warning("You don't seem to run the pigment frontend." \
+                         " Can't connect to the player.")
+                    return
+
                 bus = common.application.bus
-                bus.register(self._components_loaded, ComponentsLoadedMessage)
+                bus.register(self._frontend_loaded, PigmentFrontendLoadedMessage)
             elif blocking_mode == 2:
                 self.info("Using full-block mode")
                 dfr = self._inhibit('running')
@@ -129,12 +138,9 @@ class GnomeScreensaverService(ServiceProvider):
         dfr.addCallback(got_reply)
         return dfr
 
-    def _components_loaded(self, msg, sender):
-        # FIXME: this is ugly, is there a better way to get the players?
-        frontends = common.application.interface_controller.frontends
-        frontend = frontends.values()[0]
-        controllers = frontend.retrieve_controllers('/poblesec')
-        poblesec = controllers[0]
+    def _frontend_loaded(self, msg, sender):
+        poblesec = msg.controller
+
         poblesec.video_player.player.connect('status-changed', self._player_status_cb)
         poblesec.music_player.player.connect('status-changed', self._player_status_cb)
         poblesec.slideshow_player.player.connect('status-changed', self._player_status_cb)
