@@ -17,23 +17,28 @@
 # Author: Jesús Corrius i Llavina <jcorrius@fluendo.com>
 
 from elisa.core.components.service_provider import ServiceProvider
+from elisa.core.utils import defer
 
 from win32gui import SystemParametersInfo
 from win32con import SPI_GETSCREENSAVEACTIVE, SPI_SETSCREENSAVEACTIVE
 
+
 class WinScreenSaver(ServiceProvider):
+
     """
     Elisa service to automatically manage Microsoft Windows'
     screensaver activation and deactivation during runtime.
     """
-    
+
     def start(self):
         self._active = SystemParametersInfo(SPI_GETSCREENSAVEACTIVE)
         if self._active:
             SystemParametersInfo(SPI_SETSCREENSAVEACTIVE, False)
             self.debug('Windows screensaver disabled.')
+        return defer.succeed(None)
 
     def stop(self):
         if self._active:
             SystemParametersInfo(SPI_SETSCREENSAVEACTIVE, True)
             self.debug('Windows screensaver enabled.')
+        return defer.succeed(None)
